@@ -1,15 +1,13 @@
-# coding: utf-8
-#
 # This file is part of Supysonic.
 # Supysonic is a Python implementation of the Subsonic server API.
 #
-# Copyright (C) 2013-2018 Alban 'spl0k' Féron
+# Copyright (C) 2013-2020 Alban 'spl0k' Féron
 #
 # Distributed under terms of the GNU AGPLv3 license.
 
 from datetime import timedelta
 from flask import request
-from pony.orm import select, desc, avg, max, min, count
+from pony.orm import select, desc, avg, max, min, count, between
 
 from ..db import (
     Folder,
@@ -85,20 +83,20 @@ def album_list():
             dict(
                 album=[
                     a.as_subsonic_child(request.user)
-                    for a in query.without_distinct().random(size)
+                    for a in query.distinct().random(size)
                 ]
             ),
         )
     elif ltype == "newest":
-        query = query.order_by(desc(Folder.created)).distinct()
+        query = query.sort_by(desc(Folder.created)).distinct()
     elif ltype == "highest":
-        query = query.order_by(lambda f: desc(avg(f.ratings.rating)))
+        query = query.sort_by(lambda f: desc(avg(f.ratings.rating)))
     elif ltype == "frequent":
-        query = query.order_by(lambda f: desc(avg(f.tracks.play_count)))
+        query = query.sort_by(lambda f: desc(avg(f.tracks.play_count)))
     elif ltype == "recent":
         query = select(
             t.folder for t in Track if max(t.folder.tracks.last_play) is not None
-        ).order_by(lambda f: desc(max(f.tracks.last_play)))
+        ).sort_by(lambda f: desc(max(f.tracks.last_play)))
     elif ltype == "starred":
         query = select(
             s.starred
@@ -106,9 +104,22 @@ def album_list():
             if s.user.id == request.user.id and count(s.starred.tracks) > 0
         )
     elif ltype == "alphabeticalByName":
-        query = query.order_by(Folder.name)
+        query = query.sort_by(Folder.name).distinct()
     elif ltype == "alphabeticalByArtist":
-        query = query.order_by(lambda f: f.parent.name + f.name)
+        query = query.sort_by(lambda f: f.parent.name + f.name)
+    elif ltype == "byYear":
+        startyear = int(request.values["fromYear"])
+        endyear = int(request.values["toYear"])
+        query = query.where(
+            lambda t: between(t.year, min(startyear, endyear), max(startyear, endyear))
+        )
+        if endyear < startyear:
+            query = query.sort_by(lambda f: desc(min(f.tracks.year)))
+        else:
+            query = query.sort_by(lambda f: min(f.tracks.year))
+    elif ltype == "byGenre":
+        genre = request.values["genre"]
+        query = query.where(lambda t: t.genre == genre)
     else:
         raise GenericError("Unknown search type")
 
@@ -148,6 +159,21 @@ def album_list_id3():
         query = query.order_by(Album.name)
     elif ltype == "alphabeticalByArtist":
         query = query.order_by(lambda a: a.artist.name + a.name)
+    elif ltype == "byYear":
+        startyear = int(request.values["fromYear"])
+        endyear = int(request.values["toYear"])
+        query = query.where(
+            lambda a: between(
+                min(a.tracks.year), min(startyear, endyear), max(startyear, endyear)
+            )
+        )
+        if endyear < startyear:
+            query = query.order_by(lambda a: desc(min(a.tracks.year)))
+        else:
+            query = query.order_by(lambda a: min(a.tracks.year))
+    elif ltype == "byGenre":
+        genre = request.values["genre"]
+        query = query.where(lambda a: genre in a.tracks.genre)
     else:
         raise GenericError("Unknown search type")
 
@@ -205,7 +231,7 @@ def get_starred():
         "starred",
         dict(
             artist=[
-                dict(id=str(sf.id), name=sf.name)
+                sf.as_subsonic_artist(request.user)
                 for sf in folders.filter(lambda f: count(f.tracks) == 0)
             ],
             album=[
